(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     45258,        938]
NotebookOptionsPosition[     45677,        929]
NotebookOutlinePosition[     46112,        948]
CellTagsIndexPosition[     46069,        945]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Stress-strain relations", "Title",
 TextAlignment->Center,
 ExpressionUUID -> "8f86a5ca-ca9b-43b3-9e67-324e25bc6ded"],

Cell["\<\
Modified by: Niemann Pest and Zhelong He 
UVa Civil Engineering - February 5th, 2018\
\>", "Subtitle",
 TextAlignment->Center,
 ExpressionUUID -> "d6782260-bbcb-49ae-b501-da266d8281d4"],

Cell[TextData[{
 "This module is a slight modification of the module \
\[OpenCurlyDoubleQuote]CauchyAndEngineeringStrainDeformationIn3D\
\[CloseCurlyDoubleQuote] available on the Mathematica Demonstrations website.\
\n\nThis module demonstrates the deformations and strains that arise in an \
infinitesimal  cubical element of a material due to the application of single \
or combined stresses. The stresses applied cause a deformation of the cube \
that depend on the magnitude of the material properties (Young\
\[CloseCurlyQuote]s Modulus: E and Poisson\[CloseCurlyQuote]s Ratio: ",
 StyleBox["v",
  FontSlant->"Italic"],
 "). All stresses and resulting strains are shown in tensorial form below on \
the left side of the box, while the deformation of the cube is shown on the \
right.\n\nAdjust the sliders to change the stress components applied to the \
cube. The \[OpenCurlyDoubleQuote]reset view\[CloseCurlyDoubleQuote] button \
returns the cube to its default orientation. The \[OpenCurlyDoubleQuote]reset \
stress\[CloseCurlyDoubleQuote] button returns all stresses to zero. You can \
rotate the view of the cube by clicking and dragging on the cube. The \
matrices represent the stress and strain tensor components acting on the \
cube. The controls at the bottom adjust the view of the cube. Positive \
stresses indicate tension and the resulting positive strains are elongation."
}], "Text",
 ExpressionUUID -> "047e7fa2-c687-43c9-895b-c4a2710cf367"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`plotStyle$$ = 1, $CellContext`reset$$ = 
    False, $CellContext`showAxes$$ = True, $CellContext`showOriginal$$ = 
    True, $CellContext`strainType$$ = "eng", $CellContext`\[Gamma]xy$$ = 
    0.0078000000000000005`, $CellContext`\[Gamma]yz$$ = 
    0., $CellContext`\[Gamma]zx$$ = 0., $CellContext`\[Epsilon]x$$ = 
    0., $CellContext`\[Epsilon]y$$ = 0., $CellContext`\[Epsilon]z$$ = 
    0., $CellContext`\[Sigma]xx$$ = 0, $CellContext`\[Sigma]yy$$ = 
    0, $CellContext`\[Sigma]zz$$ = 0, $CellContext`\[Tau]xyxy$$ = 
    300, $CellContext`\[Tau]yzyz$$ = 0, $CellContext`\[Tau]zxzx$$ = 0, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`\[Sigma]xx$$], 0, ""}, -500, 500, 1}, {{
       Hold[$CellContext`\[Sigma]yy$$], 0, ""}, -500, 500, 1}, {{
       Hold[$CellContext`\[Sigma]zz$$], 0, ""}, -500, 500, 1}, {{
       Hold[$CellContext`\[Tau]xyxy$$], 300, ""}, -500, 500, 1}, {{
       Hold[$CellContext`\[Tau]yzyz$$], 0, ""}, -500, 500, 1}, {{
       Hold[$CellContext`\[Tau]zxzx$$], 0, ""}, -500, 500, 1}, {{
       Hold[$CellContext`showOriginal$$], True, ""}, {True, False}}, {{
       Hold[$CellContext`showAxes$$], True, ""}, {True, False}}, {
      Hold[
       Text[
        Grid[{{
           Grid[{{
              Spacer[39], 
              TraditionalForm[
               HoldForm[
                Subscript[$CellContext`\[Sigma], $CellContext`x]]], 
              Manipulate`Place[1], 
              Spacer[1], 
              Dynamic[
               
               AccountingForm[$CellContext`\[Sigma]xx$$, 3, 
                NumberSigns -> {"-", "+"}, SignPadding -> True]], 
              Spacer[3], "MPa"}, {
              Spacer[1], 
              TraditionalForm[
               HoldForm[
                Subscript[$CellContext`\[Sigma], $CellContext`y]]], 
              Manipulate`Place[2], 
              Spacer[1], 
              Dynamic[
               
               AccountingForm[$CellContext`\[Sigma]yy$$, 3, 
                NumberSigns -> {"-", "+"}, SignPadding -> True]], 
              Spacer[3], "MPa"}, {
              Spacer[1], 
              TraditionalForm[
               HoldForm[
                Subscript[$CellContext`\[Sigma], $CellContext`z]]], 
              Manipulate`Place[3], 
              Spacer[1], 
              Dynamic[
               
               AccountingForm[$CellContext`\[Sigma]zz$$, 3, 
                NumberSigns -> {"-", "+"}, SignPadding -> True]], 
              Spacer[3], "MPa"}, {
              Spacer[1], 
              TraditionalForm[
               HoldForm[
                Subscript[$CellContext`\[Tau], $CellContext`xy]]], 
              Manipulate`Place[4], 
              Spacer[1], 
              Dynamic[
               
               AccountingForm[$CellContext`\[Tau]xyxy$$, 3, 
                NumberSigns -> {"-", "+"}, SignPadding -> True]], 
              Spacer[3], "MPa"}, {
              Spacer[1], 
              TraditionalForm[
               HoldForm[
                Subscript[$CellContext`\[Tau], $CellContext`yz]]], 
              Manipulate`Place[5], 
              Spacer[1], 
              Dynamic[
               
               AccountingForm[$CellContext`\[Tau]yzyz$$, 3, 
                NumberSigns -> {"-", "+"}, SignPadding -> True]], 
              Spacer[3], "MPa"}, {
              Spacer[1], 
              TraditionalForm[
               HoldForm[
                Subscript[$CellContext`\[Tau], $CellContext`zx]]], 
              Manipulate`Place[6], 
              Spacer[1], 
              Dynamic[
               
               AccountingForm[$CellContext`\[Tau]zxzx$$, 3, 
                NumberSigns -> {"-", "+"}, SignPadding -> True]], 
              Spacer[3], "MPa"}}, Alignment -> Left, Spacings -> {0.4, 0.2}, 
            Frame -> False, FrameStyle -> Directive[
              Thickness[0.005], 
              GrayLevel[0.5]]]}, {
           Grid[{{
              Button[
              "reset view", $CellContext`reset$$ = True, 
               ImageSize -> {95, 28}], 
              Spacer[3], 
              Button[
              "reset stress", $CellContext`\[Sigma]xx$$ = 
                0; $CellContext`\[Sigma]yy$$ = 0; $CellContext`\[Sigma]zz$$ = 
                0; $CellContext`\[Tau]xyxy$$ = 0; $CellContext`\[Tau]yzyz$$ = 
                0; $CellContext`\[Tau]zxzx$$ = 0, ImageSize -> {95, 28}]}}]}, {
           Grid[{{
              Spacer[11], 
              Style["stress tensor (MPa)", 11], 
              Spacer[11]}, {
              Style[
               Row[{
                 Text[
                  Style[
                   TraditionalForm[
                    HoldForm[{{
                    Subscript[$CellContext`\[Sigma], $CellContext`x], 
                    Subscript[$CellContext`\[Tau], $CellContext`xy], 
                    Subscript[$CellContext`\[Tau], $CellContext`xz]}, {
                    Subscript[$CellContext`\[Tau], $CellContext`yx], 
                    Subscript[$CellContext`\[Sigma], $CellContext`y], 
                    Subscript[$CellContext`\[Tau], $CellContext`yz]}, {
                    Subscript[$CellContext`\[Tau], $CellContext`zx], 
                    Subscript[$CellContext`\[Tau], $CellContext`zy], 
                    Subscript[$CellContext`\[Sigma], $CellContext`z]}}]]]], 
                 " = ", 
                 Dynamic[
                  TraditionalForm[{{
                    
                    AccountingForm[$CellContext`\[Sigma]xx$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    
                    AccountingForm[$CellContext`\[Tau]xyxy$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    
                    AccountingForm[$CellContext`\[Tau]zxzx$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True]}, {
                    
                    AccountingForm[$CellContext`\[Tau]xyxy$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    
                    AccountingForm[$CellContext`\[Sigma]yy$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    
                    AccountingForm[$CellContext`\[Tau]yzyz$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True]}, {
                    
                    AccountingForm[$CellContext`\[Tau]zxzx$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    
                    AccountingForm[$CellContext`\[Tau]yzyz$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    
                    AccountingForm[$CellContext`\[Sigma]zz$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True]}}]]}], 
               11], SpanFromLeft}}, Alignment -> Center, 
            Spacings -> {6.5, 0.8}, Frame -> False, FrameStyle -> Directive[
              Thickness[0.005], 
              GrayLevel[0.5]]]}, {
           Grid[{{
              Style["strain tensor", 11]}, {
              Style[
               Row[{
                 Text[
                  Style[
                   TraditionalForm[
                    HoldForm[{{
                    Subscript[$CellContext`\[Epsilon], $CellContext`x], 
                    Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`xy], Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`xz]}, {
                    Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`yx], 
                    Subscript[$CellContext`\[Epsilon], $CellContext`y], 
                    Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`yz]}, {
                    Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`zx], Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`zy], 
                    Subscript[$CellContext`\[Epsilon], $CellContext`z]}}]]]], 
                 " = ", 
                 Dynamic[
                  TraditionalForm[{{
                    $CellContext`padIt1[
                    100 $CellContext`\[Epsilon]x$$, {5, 
                    4}], $CellContext`padIt1[(180/Pi) 
                    If[$CellContext`strainType$$ == 
                    "eng", $CellContext`\[Gamma]xy$$, \
$CellContext`\[Gamma]xy$$/2], {5, 4}]^
                    Degree, $CellContext`padIt1[(180/
                    Pi) ($CellContext`\[Gamma]zx$$/
                    If[$CellContext`strainType$$ == "eng", 1, 2]), {5, 4}]^
                    Degree}, {$CellContext`padIt1[(180/
                    Pi) ($CellContext`\[Gamma]xy$$/
                    If[$CellContext`strainType$$ == "eng", 1, 2]), {5, 4}]^
                    Degree, 
                    $CellContext`padIt1[
                    100 $CellContext`\[Epsilon]y$$, {5, 
                    4}], $CellContext`padIt1[(180/
                    Pi) ($CellContext`\[Gamma]yz$$/
                    If[$CellContext`strainType$$ == "eng", 1, 2]), {5, 4}]^
                    Degree}, {$CellContext`padIt1[(180/
                    Pi) ($CellContext`\[Gamma]zx$$/
                    If[$CellContext`strainType$$ == "eng", 1, 2]), {5, 4}]^
                    Degree, $CellContext`padIt1[(180/
                    Pi) ($CellContext`\[Gamma]yz$$/
                    If[$CellContext`strainType$$ == "eng", 1, 2]), {5, 4}]^
                    Degree, 
                    $CellContext`padIt1[
                    100 $CellContext`\[Epsilon]z$$, {5, 4}]}}]]}], 11]}}, 
            Alignment -> Center, Spacings -> {0.3, 1}, Frame -> False, 
            FrameStyle -> Directive[
              Thickness[0.005], 
              GrayLevel[0.5]]]}, {
           Grid[{{
              Row[{
                Text[
                 Style["show original", 12]], 
                Manipulate`Place[7]}], 
              Row[{
                Text[
                 Style["show axes", 12]], 
                Manipulate`Place[8]}], 
              Row[{
                Style["cube style", 12], 
                RadioButtonBar[
                 Dynamic[$CellContext`plotStyle$$], {1, 2}]}]}}, Alignment -> 
            Left, Spacings -> {1, 0.4}, Frame -> True, FrameStyle -> Directive[
              Thickness[0.005], 
              GrayLevel[0.5]]]}}, Alignment -> Center]]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`strainType$$], "eng"}, 0}, {{
       Hold[$CellContext`plotStyle$$], 1}, 0}, {{
       Hold[$CellContext`reset$$], False}, 0}, {{
       Hold[$CellContext`\[Epsilon]x$$], 0}, 0}, {{
       Hold[$CellContext`\[Epsilon]y$$], 0}, 0}, {{
       Hold[$CellContext`\[Epsilon]z$$], 0}, 0}, {{
       Hold[$CellContext`\[Gamma]xy$$], 0}, 0}, {{
       Hold[$CellContext`\[Gamma]yz$$], 0}, 0}, {{
       Hold[$CellContext`\[Gamma]zx$$], 0}, 0}}, Typeset`size$$ = {
    292., {213., 219.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`\[Sigma]xx$4228$$ = 
    0, $CellContext`\[Sigma]yy$4229$$ = 0, $CellContext`\[Sigma]zz$4230$$ = 
    0, $CellContext`\[Tau]xyxy$4231$$ = 0, $CellContext`\[Tau]yzyz$4232$$ = 
    0, $CellContext`\[Tau]zxzx$4233$$ = 0, $CellContext`showOriginal$4234$$ = 
    False, $CellContext`showAxes$4235$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`plotStyle$$ = 1, $CellContext`reset$$ = 
        False, $CellContext`showAxes$$ = True, $CellContext`showOriginal$$ = 
        True, $CellContext`strainType$$ = "eng", $CellContext`\[Gamma]xy$$ = 
        0, $CellContext`\[Gamma]yz$$ = 0, $CellContext`\[Gamma]zx$$ = 
        0, $CellContext`\[Epsilon]x$$ = 0, $CellContext`\[Epsilon]y$$ = 
        0, $CellContext`\[Epsilon]z$$ = 0, $CellContext`\[Sigma]xx$$ = 
        0, $CellContext`\[Sigma]yy$$ = 0, $CellContext`\[Sigma]zz$$ = 
        0, $CellContext`\[Tau]xyxy$$ = 300, $CellContext`\[Tau]yzyz$$ = 
        0, $CellContext`\[Tau]zxzx$$ = 0}, "ControllerVariables" :> {
        Hold[$CellContext`\[Sigma]xx$$, $CellContext`\[Sigma]xx$4228$$, 0], 
        Hold[$CellContext`\[Sigma]yy$$, $CellContext`\[Sigma]yy$4229$$, 0], 
        Hold[$CellContext`\[Sigma]zz$$, $CellContext`\[Sigma]zz$4230$$, 0], 
        Hold[$CellContext`\[Tau]xyxy$$, $CellContext`\[Tau]xyxy$4231$$, 0], 
        Hold[$CellContext`\[Tau]yzyz$$, $CellContext`\[Tau]yzyz$4232$$, 0], 
        Hold[$CellContext`\[Tau]zxzx$$, $CellContext`\[Tau]zxzx$4233$$, 0], 
        Hold[$CellContext`showOriginal$$, $CellContext`showOriginal$4234$$, 
         False], 
        Hold[$CellContext`showAxes$$, $CellContext`showAxes$4235$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`g$, $CellContext`p1$, $CellContext`p2$, \
$CellContext`p3$, $CellContext`p4$, $CellContext`p5$, $CellContext`p6$, \
$CellContext`p7$, $CellContext`p8$, $CellContext`e$ = 
         100 10^9, $CellContext`\[Nu]$ = 
         0.3, $CellContext`\[Sigma]x$ = $CellContext`\[Sigma]xx$$ 
          10^6, $CellContext`\[Sigma]y$ = $CellContext`\[Sigma]yy$$ 
          10^6, $CellContext`\[Sigma]z$ = $CellContext`\[Sigma]zz$$ 
          10^6, $CellContext`\[Tau]xy$ = $CellContext`\[Tau]xyxy$$ 
          10^6, $CellContext`\[Tau]yz$ = $CellContext`\[Tau]yzyz$$ 
          10^6, $CellContext`\[Tau]zx$ = $CellContext`\[Tau]zxzx$$ 
          10^6, $CellContext`k$ = 
         35}, $CellContext`g$ = $CellContext`e$/(
          2 (1 + $CellContext`\[Nu]$)); $CellContext`\[Epsilon]x$$ = \
$CellContext`\[Sigma]x$/$CellContext`e$ - \
($CellContext`\[Nu]$/$CellContext`e$) ($CellContext`\[Sigma]y$ + \
$CellContext`\[Sigma]z$); $CellContext`\[Epsilon]y$$ = \
$CellContext`\[Sigma]y$/$CellContext`e$ - \
($CellContext`\[Nu]$/$CellContext`e$) ($CellContext`\[Sigma]x$ + \
$CellContext`\[Sigma]z$); $CellContext`\[Epsilon]z$$ = \
$CellContext`\[Sigma]z$/$CellContext`e$ - \
($CellContext`\[Nu]$/$CellContext`e$) ($CellContext`\[Sigma]y$ + \
$CellContext`\[Sigma]x$); $CellContext`\[Gamma]xy$$ = \
$CellContext`\[Tau]xy$/$CellContext`g$; $CellContext`\[Gamma]yz$$ = \
$CellContext`\[Tau]yz$/$CellContext`g$; $CellContext`\[Gamma]zx$$ = \
$CellContext`\[Tau]zx$/$CellContext`g$; {$CellContext`p1$, $CellContext`p2$, \
$CellContext`p3$, $CellContext`p4$, $CellContext`p5$, $CellContext`p6$, \
$CellContext`p7$, $CellContext`p8$} = \
$CellContext`getCoordinates[$CellContext`strainType$$, \
$CellContext`\[Epsilon]x$$, $CellContext`\[Epsilon]y$$, $CellContext`\
\[Epsilon]z$$, $CellContext`\[Gamma]xy$$, $CellContext`\[Gamma]yz$$, \
$CellContext`\[Gamma]zx$$, $CellContext`k$]; Style[
          Framed[
           Graphics3D[
            Rotate[{
              If[$CellContext`plotStyle$$ == 1, {{
                 EdgeForm[{Thick, Red}], 
                 FaceForm[
                  Opacity[0.3]], 
                 
                 Polygon[{$CellContext`p1$, $CellContext`p2$, \
$CellContext`p3$, $CellContext`p4$}], 
                 
                 Polygon[{$CellContext`p5$, $CellContext`p6$, \
$CellContext`p7$, $CellContext`p8$}], 
                 
                 Polygon[{$CellContext`p4$, $CellContext`p3$, \
$CellContext`p7$, $CellContext`p8$}], 
                 
                 Polygon[{$CellContext`p1$, $CellContext`p2$, \
$CellContext`p6$, $CellContext`p5$}], 
                 
                 Polygon[{$CellContext`p2$, $CellContext`p6$, \
$CellContext`p7$, $CellContext`p3$}], 
                 
                 Polygon[{$CellContext`p4$, $CellContext`p8$, \
$CellContext`p5$, $CellContext`p1$}]}}, {{
                 FaceForm[{
                   Opacity[0.3]}, White], 
                 
                 Polygon[{$CellContext`p1$, $CellContext`p2$, \
$CellContext`p3$, $CellContext`p4$}], 
                 
                 Polygon[{$CellContext`p5$, $CellContext`p6$, \
$CellContext`p7$, $CellContext`p8$}], 
                 
                 Polygon[{$CellContext`p4$, $CellContext`p3$, \
$CellContext`p7$, $CellContext`p8$}], 
                 
                 Polygon[{$CellContext`p1$, $CellContext`p2$, \
$CellContext`p6$, $CellContext`p5$}], 
                 
                 Polygon[{$CellContext`p2$, $CellContext`p6$, \
$CellContext`p7$, $CellContext`p3$}], 
                 
                 Polygon[{$CellContext`p4$, $CellContext`p8$, \
$CellContext`p5$, $CellContext`p1$}]}}], 
              If[$CellContext`showOriginal$$, {Gray, Dashed, 
                
                Line[{{(-1)/2, (-1)/2, 1/2}, {1/2, (-1)/2, 1/2}, {
                  1/2, (-1)/2, (-1)/2}, {(-1)/2, (-1)/2, (-1)/2}, {(-1)/
                   2, (-1)/2, 1/2}}], 
                
                Line[{{(-1)/2, 1/2, 1/2}, {1/2, 1/2, 1/2}, {
                  1/2, 1/2, (-1)/2}, {(-1)/2, 1/2, (-1)/2}, {(-1)/2, 1/2, 1/
                   2}}], 
                Line[{{(-1)/2, (-1)/2, (-1)/2}, {(-1)/2, 1/2, (-1)/2}}], 
                Line[{{1/2, (-1)/2, (-1)/2}, {1/2, 1/2, (-1)/2}}], 
                Line[{{(-1)/2, (-1)/2, 1/2}, {(-1)/2, 1/2, 1/2}}], 
                Line[{{1/2, (-1)/2, 1/2}, {1/2, 1/2, 1/2}}]}, {}], 
              If[$CellContext`showAxes$$, {{
                 Arrowheads[0.02], 
                 Map[
                 Arrow[{{0, 0, 0}, #}]& , {{0.25, 0, 0}, {0, 0.25, 0}, {
                   0, 0, 0.25}}]}, {
                 Text[
                  Style["x", Italic, FontSize -> Scaled[0.04]], {0.28, 0, 0}], 
                 Text[
                  Style["y", Italic, FontSize -> Scaled[0.04]], {0, 0.28, 0}], 
                 Text[
                  Style["z", Italic, FontSize -> Scaled[0.04]], {
                  0, 0, 0.28}]}}, {}]}, 90 Degree, {1, 0, 0}], 
            PlotRange -> {{-1.3, 1.3}, {-1.4, 1.4}, {-1.4, 1.4}}, Boxed -> 
            False, ImagePadding -> 0.1, ImageMargins -> 0, SphericalRegion -> 
            True, ViewPoint -> {4.86215, -27.5746, 5}, 
            
            If[$CellContext`plotStyle$$ == 1, 
             Lighting -> {{"Ambient", White}}, Lighting -> Automatic], 
            ViewAngle -> 2 (Pi/180), PreserveImageOptions -> 
            If[$CellContext`reset$$, $CellContext`reset$$ = False; False, 
              True], ImageSize -> {280, 420}]], Antialiasing -> True]], 
      "Specifications" :> {{{$CellContext`\[Sigma]xx$$, 0, ""}, -500, 500, 1, 
         ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`\[Sigma]yy$$, 0, ""}, -500, 500, 1, ImageSize -> 
         Tiny, ControlPlacement -> 
         2}, {{$CellContext`\[Sigma]zz$$, 0, ""}, -500, 500, 1, ImageSize -> 
         Tiny, ControlPlacement -> 
         3}, {{$CellContext`\[Tau]xyxy$$, 300, ""}, -500, 500, 1, ImageSize -> 
         Tiny, ControlPlacement -> 
         4}, {{$CellContext`\[Tau]yzyz$$, 0, ""}, -500, 500, 1, ImageSize -> 
         Tiny, ControlPlacement -> 
         5}, {{$CellContext`\[Tau]zxzx$$, 0, ""}, -500, 500, 1, ImageSize -> 
         Tiny, ControlPlacement -> 
         6}, {{$CellContext`showOriginal$$, True, ""}, {True, False}, 
         ControlPlacement -> 7}, {{$CellContext`showAxes$$, True, ""}, {
         True, False}, ControlPlacement -> 8}, 
        Text[
         Grid[{{
            Grid[{{
               Spacer[39], 
               TraditionalForm[
                HoldForm[
                 Subscript[$CellContext`\[Sigma], $CellContext`x]]], 
               Manipulate`Place[1], 
               Spacer[1], 
               Dynamic[
                
                AccountingForm[$CellContext`\[Sigma]xx$$, 3, 
                 NumberSigns -> {"-", "+"}, SignPadding -> True]], 
               Spacer[3], "MPa"}, {
               Spacer[1], 
               TraditionalForm[
                HoldForm[
                 Subscript[$CellContext`\[Sigma], $CellContext`y]]], 
               Manipulate`Place[2], 
               Spacer[1], 
               Dynamic[
                AccountingForm[$CellContext`\[Sigma]yy$$, 3, 
                 NumberSigns -> {"-", "+"}, SignPadding -> True]], 
               Spacer[3], "MPa"}, {
               Spacer[1], 
               TraditionalForm[
                HoldForm[
                 Subscript[$CellContext`\[Sigma], $CellContext`z]]], 
               Manipulate`Place[3], 
               Spacer[1], 
               Dynamic[
                
                AccountingForm[$CellContext`\[Sigma]zz$$, 3, 
                 NumberSigns -> {"-", "+"}, SignPadding -> True]], 
               Spacer[3], "MPa"}, {
               Spacer[1], 
               TraditionalForm[
                HoldForm[
                 Subscript[$CellContext`\[Tau], $CellContext`xy]]], 
               Manipulate`Place[4], 
               Spacer[1], 
               Dynamic[
                
                AccountingForm[$CellContext`\[Tau]xyxy$$, 3, 
                 NumberSigns -> {"-", "+"}, SignPadding -> True]], 
               Spacer[3], "MPa"}, {
               Spacer[1], 
               TraditionalForm[
                HoldForm[
                 Subscript[$CellContext`\[Tau], $CellContext`yz]]], 
               Manipulate`Place[5], 
               Spacer[1], 
               Dynamic[
                
                AccountingForm[$CellContext`\[Tau]yzyz$$, 3, 
                 NumberSigns -> {"-", "+"}, SignPadding -> True]], 
               Spacer[3], "MPa"}, {
               Spacer[1], 
               TraditionalForm[
                HoldForm[
                 Subscript[$CellContext`\[Tau], $CellContext`zx]]], 
               Manipulate`Place[6], 
               Spacer[1], 
               Dynamic[
                
                AccountingForm[$CellContext`\[Tau]zxzx$$, 3, 
                 NumberSigns -> {"-", "+"}, SignPadding -> True]], 
               Spacer[3], "MPa"}}, Alignment -> Left, Spacings -> {0.4, 0.2}, 
             Frame -> False, FrameStyle -> Directive[
               Thickness[0.005], 
               GrayLevel[0.5]]]}, {
            Grid[{{
               Button[
               "reset view", $CellContext`reset$$ = True, 
                ImageSize -> {95, 28}], 
               Spacer[3], 
               Button[
               "reset stress", $CellContext`\[Sigma]xx$$ = 
                 0; $CellContext`\[Sigma]yy$$ = 0; $CellContext`\[Sigma]zz$$ = 
                 0; $CellContext`\[Tau]xyxy$$ = 0; $CellContext`\[Tau]yzyz$$ = 
                 0; $CellContext`\[Tau]zxzx$$ = 0, 
                ImageSize -> {95, 28}]}}]}, {
            Grid[{{
               Spacer[11], 
               Style["stress tensor (MPa)", 11], 
               Spacer[11]}, {
               Style[
                Row[{
                  Text[
                   Style[
                    TraditionalForm[
                    HoldForm[{{
                    Subscript[$CellContext`\[Sigma], $CellContext`x], 
                    Subscript[$CellContext`\[Tau], $CellContext`xy], 
                    Subscript[$CellContext`\[Tau], $CellContext`xz]}, {
                    Subscript[$CellContext`\[Tau], $CellContext`yx], 
                    Subscript[$CellContext`\[Sigma], $CellContext`y], 
                    Subscript[$CellContext`\[Tau], $CellContext`yz]}, {
                    Subscript[$CellContext`\[Tau], $CellContext`zx], 
                    Subscript[$CellContext`\[Tau], $CellContext`zy], 
                    Subscript[$CellContext`\[Sigma], $CellContext`z]}}]]]], 
                  " = ", 
                  Dynamic[
                   TraditionalForm[{{
                    
                    AccountingForm[$CellContext`\[Sigma]xx$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    
                    AccountingForm[$CellContext`\[Tau]xyxy$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    
                    AccountingForm[$CellContext`\[Tau]zxzx$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True]}, {
                    
                    AccountingForm[$CellContext`\[Tau]xyxy$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    AccountingForm[$CellContext`\[Sigma]yy$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    
                    AccountingForm[$CellContext`\[Tau]yzyz$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True]}, {
                    
                    AccountingForm[$CellContext`\[Tau]zxzx$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    
                    AccountingForm[$CellContext`\[Tau]yzyz$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True], 
                    
                    AccountingForm[$CellContext`\[Sigma]zz$$, 3, 
                    NumberSigns -> {"-", "+"}, SignPadding -> True]}}]]}], 
                11], SpanFromLeft}}, Alignment -> Center, 
             Spacings -> {6.5, 0.8}, Frame -> False, FrameStyle -> Directive[
               Thickness[0.005], 
               GrayLevel[0.5]]]}, {
            Grid[{{
               Style["strain tensor", 11]}, {
               Style[
                Row[{
                  Text[
                   Style[
                    TraditionalForm[
                    HoldForm[{{
                    Subscript[$CellContext`\[Epsilon], $CellContext`x], 
                    Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`xy], Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`xz]}, {
                    Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`yx], 
                    Subscript[$CellContext`\[Epsilon], $CellContext`y], 
                    Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`yz]}, {
                    Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`zx], Dynamic[
                    If[$CellContext`strainType$$ == "eng", 
                    Spacer[12], 
                    Style["1/2", 8]]] 
                    Subscript[$CellContext`\[Gamma], $CellContext`zy], 
                    Subscript[$CellContext`\[Epsilon], $CellContext`z]}}]]]], 
                  " = ", 
                  Dynamic[
                   TraditionalForm[{{
                    $CellContext`padIt1[
                    100 $CellContext`\[Epsilon]x$$, {5, 
                    4}], $CellContext`padIt1[(180/Pi) 
                    If[$CellContext`strainType$$ == 
                    "eng", $CellContext`\[Gamma]xy$$, \
$CellContext`\[Gamma]xy$$/2], {5, 4}]^
                    Degree, $CellContext`padIt1[(180/
                    Pi) ($CellContext`\[Gamma]zx$$/
                    If[$CellContext`strainType$$ == "eng", 1, 2]), {5, 4}]^
                    Degree}, {$CellContext`padIt1[(180/
                    Pi) ($CellContext`\[Gamma]xy$$/
                    If[$CellContext`strainType$$ == "eng", 1, 2]), {5, 4}]^
                    Degree, 
                    $CellContext`padIt1[
                    100 $CellContext`\[Epsilon]y$$, {5, 
                    4}], $CellContext`padIt1[(180/
                    Pi) ($CellContext`\[Gamma]yz$$/
                    If[$CellContext`strainType$$ == "eng", 1, 2]), {5, 4}]^
                    Degree}, {$CellContext`padIt1[(180/
                    Pi) ($CellContext`\[Gamma]zx$$/
                    If[$CellContext`strainType$$ == "eng", 1, 2]), {5, 4}]^
                    Degree, $CellContext`padIt1[(180/
                    Pi) ($CellContext`\[Gamma]yz$$/
                    If[$CellContext`strainType$$ == "eng", 1, 2]), {5, 4}]^
                    Degree, 
                    $CellContext`padIt1[
                    100 $CellContext`\[Epsilon]z$$, {5, 4}]}}]]}], 11]}}, 
             Alignment -> Center, Spacings -> {0.3, 1}, Frame -> False, 
             FrameStyle -> Directive[
               Thickness[0.005], 
               GrayLevel[0.5]]]}, {
            Grid[{{
               Row[{
                 Text[
                  Style["show original", 12]], 
                 Manipulate`Place[7]}], 
               Row[{
                 Text[
                  Style["show axes", 12]], 
                 Manipulate`Place[8]}], 
               Row[{
                 Style["cube style", 12], 
                 RadioButtonBar[
                  Dynamic[$CellContext`plotStyle$$], {1, 2}]}]}}, Alignment -> 
             Left, Spacings -> {1, 0.4}, Frame -> True, FrameStyle -> 
             Directive[
               Thickness[0.005], 
               GrayLevel[0.5]]]}}, Alignment -> 
          Center]], {{$CellContext`strainType$$, "eng"}, 0, ControlType -> 
         None}, {{$CellContext`plotStyle$$, 1}, 0, ControlType -> 
         None}, {{$CellContext`reset$$, False}, 0, ControlType -> 
         None}, {{$CellContext`\[Epsilon]x$$, 0}, 0, ControlType -> 
         None}, {{$CellContext`\[Epsilon]y$$, 0}, 0, ControlType -> 
         None}, {{$CellContext`\[Epsilon]z$$, 0}, 0, ControlType -> 
         None}, {{$CellContext`\[Gamma]xy$$, 0}, 0, ControlType -> 
         None}, {{$CellContext`\[Gamma]yz$$, 0}, 0, ControlType -> 
         None}, {{$CellContext`\[Gamma]zx$$, 0}, 0, ControlType -> None}}, 
      "Options" :> {
       ControlPlacement -> Left, SynchronousUpdating -> True, 
        SynchronousInitialization -> True, ContinuousAction -> True, 
        Alignment -> Center, ImageMargins -> 0, FrameMargins -> 0, Paneled -> 
        True, Frame -> False, 
        TrackedSymbols :> {$CellContext`\[Sigma]xx$$, \
$CellContext`\[Sigma]yy$$, $CellContext`\[Sigma]zz$$, \
$CellContext`\[Tau]xyxy$$, $CellContext`\[Tau]yzyz$$, \
$CellContext`\[Tau]zxzx$$, $CellContext`strainType$$, $CellContext`k, \
$CellContext`ee, $CellContext`\[Nu], $CellContext`reset$$, \
$CellContext`showOriginal$$, $CellContext`showAxes$$, \
$CellContext`plotStyle$$}}, "DefaultOptions" :> {}],
     ImageSizeCache->{643., {235., 241.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`integerStrictPositive = And[
         IntegerQ[#], # > 0]& ; $CellContext`integerPositive = And[
         IntegerQ[#], # >= 0]& ; $CellContext`numericStrictPositive = And[
         Element[#, Reals], # > 0]& ; $CellContext`numericPositive = And[
         Element[#, Reals], # >= 0]& ; $CellContext`numericStrictNegative = 
       And[
         Element[#, Reals], # < 0]& ; $CellContext`numericNegative = And[
         Element[#, Reals], # <= 0]& ; $CellContext`bool = 
       Element[#, Booleans]& ; $CellContext`numeric = 
       Element[#, Reals]& ; $CellContext`integer = 
       Element[#, Integers]& ; $CellContext`padIt1[
         PatternTest[
          Pattern[$CellContext`v, 
           Blank[]], $CellContext`numeric], 
         Pattern[$CellContext`f, 
          Blank[List]]] := 
       AccountingForm[$CellContext`v, $CellContext`f, 
         NumberSigns -> {"-", "+"}, SignPadding -> True]; $CellContext`padIt1[
         PatternTest[
          Pattern[$CellContext`v, 
           Blank[]], $CellContext`numeric], 
         Pattern[$CellContext`f, 
          Blank[Integer]]] := AccountingForm[
         Chop[$CellContext`v], $CellContext`f, NumberSigns -> {"-", "+"}, 
         SignPadding -> True]; $CellContext`padIt2[
         PatternTest[
          Pattern[$CellContext`v, 
           Blank[]], $CellContext`numeric], 
         Pattern[$CellContext`f, 
          Blank[List]]] := 
       AccountingForm[$CellContext`v, $CellContext`f, NumberSigns -> {"", ""},
          SignPadding -> True]; $CellContext`padIt2[
         PatternTest[
          Pattern[$CellContext`v, 
           Blank[]], $CellContext`numeric], 
         Pattern[$CellContext`f, 
          Blank[Integer]]] := AccountingForm[
         Chop[$CellContext`v], $CellContext`f, NumberSigns -> {"", ""}, 
         SignPadding -> True]; $CellContext`getCoordinates[
         Pattern[$CellContext`strainType, 
          Blank[String]], 
         PatternTest[
          Pattern[$CellContext`\[Epsilon]x, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`\[Epsilon]y, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`\[Epsilon]z, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`\[Gamma]xy, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`\[Gamma]yz, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`\[Gamma]zx, 
           Blank[]], $CellContext`numeric], 
         PatternTest[
          Pattern[$CellContext`k, 
           Blank[]], $CellContext`integerStrictPositive]] := 
       Module[{$CellContext`p1, $CellContext`p2, $CellContext`p3, \
$CellContext`p4, $CellContext`p5, $CellContext`p6, $CellContext`p7, \
$CellContext`p8, $CellContext`a\[Tau]xy, $CellContext`a\[Tau]yz, \
$CellContext`a\[Tau]zx}, $CellContext`a\[Tau]xy = 
          Sin[$CellContext`\[Gamma]xy/2]; $CellContext`a\[Tau]yz = 
          Sin[$CellContext`\[Gamma]yz/2]; $CellContext`a\[Tau]zx = 
          Sin[$CellContext`\[Gamma]zx/2]; 
         If[$CellContext`strainType == 
           "eng", $CellContext`p1 = {(-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]x)/
                 2 + $CellContext`a\[Tau]zx), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]y)/
                 2 - $CellContext`a\[Tau]xy), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]z/
                 2 - $CellContext`a\[Tau]yz)}; $CellContext`p2 = {
             1/2 + $CellContext`k ($CellContext`\[Epsilon]x/
                 2 + $CellContext`a\[Tau]zx), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]y)/
                 2 + $CellContext`a\[Tau]xy), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]z/
                 2 - $CellContext`a\[Tau]yz)}; $CellContext`p3 = {
             1/2 + $CellContext`k ($CellContext`\[Epsilon]x/
                 2 + $CellContext`a\[Tau]zx), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]y/
                 2 + $CellContext`a\[Tau]xy), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]z/
                 2 + $CellContext`a\[Tau]yz)}; $CellContext`p4 = {(-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]x)/
                 2 + $CellContext`a\[Tau]zx), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]y/
                 2 - $CellContext`a\[Tau]xy), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]z/
                 2 + $CellContext`a\[Tau]yz)}; $CellContext`p5 = {(-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]x)/
                 2 - $CellContext`a\[Tau]zx), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]y)/
                 2 - $CellContext`a\[Tau]xy), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]z)/
                 2 - $CellContext`a\[Tau]yz)}; $CellContext`p6 = {
             1/2 + $CellContext`k ($CellContext`\[Epsilon]x/
                 2 - $CellContext`a\[Tau]zx), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]y)/
                 2 + $CellContext`a\[Tau]xy), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]z)/
                 2 - $CellContext`a\[Tau]yz)}; $CellContext`p7 = {
             1/2 + $CellContext`k ($CellContext`\[Epsilon]x/
                 2 - $CellContext`a\[Tau]zx), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]y/
                 2 + $CellContext`a\[Tau]xy), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]z)/
                 2 + $CellContext`a\[Tau]yz)}; $CellContext`p8 = {(-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]x)/
                 2 - $CellContext`a\[Tau]zx), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]y/
                 2 - $CellContext`a\[Tau]xy), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]z)/
                 2 + $CellContext`a\[Tau]yz)}, $CellContext`p1 = {(-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]x)/
                 2 - $CellContext`a\[Tau]xy/
                2 + $CellContext`a\[Tau]zx/2), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]y)/
                 2 - $CellContext`a\[Tau]xy/2 + $CellContext`a\[Tau]yz/2), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]z/
                 2 - $CellContext`a\[Tau]yz/2 - $CellContext`a\[Tau]zx/
                2)}; $CellContext`p2 = {
             1/2 + $CellContext`k ($CellContext`\[Epsilon]x/
                 2 - $CellContext`a\[Tau]xy/
                2 + $CellContext`a\[Tau]zx/2), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]y)/
                 2 + $CellContext`a\[Tau]xy/2 + $CellContext`a\[Tau]yz/2), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]z/
                 2 - $CellContext`a\[Tau]yz/
                2 + $CellContext`a\[Tau]zx/2)}; $CellContext`p3 = {
             1/2 + $CellContext`k ($CellContext`\[Epsilon]x/
                 2 + $CellContext`a\[Tau]xy/2 + $CellContext`a\[Tau]zx/2), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]y/
                 2 + $CellContext`a\[Tau]xy/2 + $CellContext`a\[Tau]yz/2), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]z/
                 2 + $CellContext`a\[Tau]yz/2 + $CellContext`a\[Tau]zx/
                 2)}; $CellContext`p4 = {(-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]x)/
                 2 + $CellContext`a\[Tau]xy/2 + $CellContext`a\[Tau]zx/2), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]y/
                 2 - $CellContext`a\[Tau]xy/2 + $CellContext`a\[Tau]yz/2), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]z/
                 2 + $CellContext`a\[Tau]yz/2 - $CellContext`a\[Tau]zx/
                2)}; $CellContext`p5 = {(-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]x)/
                 2 - $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]zx/
                2), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]y)/
                 2 - $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]yz/
                2), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]z)/
                 2 - $CellContext`a\[Tau]yz/2 - $CellContext`a\[Tau]zx/
                2)}; $CellContext`p6 = {
             1/2 + $CellContext`k ($CellContext`\[Epsilon]x/
                 2 - $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]zx/
                2), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]y)/
                 2 + $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]yz/
                2), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]z)/
                 2 - $CellContext`a\[Tau]yz/
                2 + $CellContext`a\[Tau]zx/2)}; $CellContext`p7 = {
             1/2 + $CellContext`k ($CellContext`\[Epsilon]x/
                 2 + $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]zx/2), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]y/
                 2 + $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]yz/
                2), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]z)/
                 2 + $CellContext`a\[Tau]yz/2 + $CellContext`a\[Tau]zx/
                 2)}; $CellContext`p8 = {(-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]x)/
                 2 + $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]zx/2), 
              1/2 + $CellContext`k ($CellContext`\[Epsilon]y/
                 2 - $CellContext`a\[Tau]xy/2 - $CellContext`a\[Tau]yz/
                2), (-1)/
               2 + $CellContext`k ((-$CellContext`\[Epsilon]z)/
                 2 + $CellContext`a\[Tau]yz/2 - $CellContext`a\[Tau]zx/
                2)}]; {$CellContext`p1, $CellContext`p2, $CellContext`p3, \
$CellContext`p4, $CellContext`p5, $CellContext`p6, $CellContext`p7, \
$CellContext`p8}]); Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "2c2613eb-9f46-4608-8690-032d4ba23bfd"]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 123, 2, 101, "Title"],
Cell[1612, 39, 195, 5, 91, "Subtitle"],
Cell[1810, 46, 1463, 22, 144, "Text"],
Cell[3276, 70, 42385, 856, 493, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature 1vpDsKkS#YR#hB1yJ4hhkqdj *)
